Crop a Global Raster to the Extent of Planning Units
crop_global_raster.RdThis function crops a large global raster to the spatial extent of a planning units raster (pus).
It reprojects the pus extent to the coordinate reference system of the input global raster
to ensure accurate cropping. This is useful for pre-processing global inputs before using
functions like make_normalised_raster() to reduce processing time.
Ejemplos
if (FALSE) { # \dontrun{
cropped <- crop_global_raster(global_raster, pus) |>
elsar::make_normalised_raster(pus = pus, iso3 = "KEN")
} # }