Download Global Pasture Watch Grassland Probability Layer
download_global_pasture_data.RdDownloads either the cultivated or natural/semi-natural grassland probability layer from the Global Pasture Watch dataset hosted in Earth Engine. Returns the result as a local Cloud-Optimized GeoTIFF with appropriate layer naming.
Argumentos
- boundary_layer
An
sfobject defining the spatial boundary of interest.- iso3
Character. Three-letter ISO country code for filename generation.
- gee_project
Character. Google Earth Engine cloud project ID. This is required and must be a valid GEE project you have access to. Find your project ID in the GEE Code Editor.
- output_dir
Character. Local output directory. Defaults to project root via
here::here()- layer_type
Character. One of "cultivated" (default) or "natural" to specify which grassland probability layer to download
- ...
Additional arguments passed to
download_gee_layer().